==> libopenmpt-0.4.50-pre.0+r23541.doc.tar.gz: libopenmpt-0.4.50-pre.0+r23541.doc/docs/group__libopenmpt__ext__cpp.js <==
var group__libopenmpt__ext__cpp =
[
    [ "module_ext", "classopenmpt_1_1module__ext.html", [
      [ "module_ext", "classopenmpt_1_1module__ext.html#a4994cb67b264d14aa849ec2067c6076b", null ],
      [ "module_ext", "classopenmpt_1_1module__ext.html#a31595d7291f0a1fec0f827f1a4a3296d", null ],
      [ "module_ext", "classopenmpt_1_1module__ext.html#a7914d17a610f62eb3b5e8cddeaacbec8", null ],
      [ "module_ext", "classopenmpt_1_1module__ext.html#ac7eaa75faea847d4a63c37e95f745d7a", null ],
      [ "~module_ext", "classopenmpt_1_1module__ext.html#a24ad229c4c23cd7ec9de328e09cdf3dc", null ],
      [ "get_interface", "classopenmpt_1_1module__ext.html#aa98f2d2bb046ea2bc346b8f4839c65ce", null ]
    ] ],
    [ "pattern_vis", "classopenmpt_1_1ext_1_1pattern__vis.html", [
      [ "effect_type", "classopenmpt_1_1ext_1_1pattern__vis.html#a42fdf7dfd8919fa42a8bbb7754cccde3", [
        [ "effect_unknown", "classopenmpt_1_1ext_1_1pattern__vis.html#a42fdf7dfd8919fa42a8bbb7754cccde3af10aa914735334b1de44aeec4870345a", null ],
        [ "effect_general", "classopenmpt_1_1ext_1_1pattern__vis.html#a42fdf7dfd8919fa42a8bbb7754cccde3a2723a45bc3a57aefe507bcc7e8729ede", null ],
        [ "effect_global", "classopenmpt_1_1ext_1_1pattern__vis.html#a42fdf7dfd8919fa42a8bbb7754cccde3a4431ac360b49a3381f32e3c50c8350e9", null ],
        [ "effect_volume", "classopenmpt_1_1ext_1_1pattern__vis.html#a42fdf7dfd8919fa42a8bbb7754cccde3a795774dd8f93ab5714e7961449be5f8c", null ],
        [ "effect_panning", "classopenmpt_1_1ext_1_1pattern__vis.html#a42fdf7dfd8919fa42a8bbb7754cccde3a7cb096c0556b747289cc9f0136f09be0", null ],
        [ "effect_pitch", "classopenmpt_1_1ext_1_1pattern__vis.html#a42fdf7dfd8919fa42a8bbb7754cccde3a1c789ea5244b97959b9b960094e8614e", null ]
      ] ],
      [ "pattern_vis", "classopenmpt_1_1ext_1_1pattern__vis.html#a6f346c9132d63b48a3217983f8570888", null ],
      [ "~ pattern_vis", "classopenmpt_1_1ext_1_1pattern__vis.html#a269636fa2e1e5a867ee7b093c5589283", null ],
      [ "get_pattern_row_channel_effect_type", "classopenmpt_1_1ext_1_1pattern__vis.html#a1c0048a3f55579336b5adcb1c901b90b", null ],
      [ "get_pattern_row_channel_volume_effect_type", "classopenmpt_1_1ext_1_1pattern__vis.html#afc9f85743bf1a24167acb0fcd899c879", null ]
    ] ],
    [ "interactive", "classopenmpt_1_1ext_1_1interactive.html", [
      [ "interactive", "classopenmpt_1_1ext_1_1interactive.html#a905dbc74186d10a96cbd929235300315", null ],
      [ "~ interactive", "classopenmpt_1_1ext_1_1interactive.html#ac4847dc829005331c0e72910e7d81707", null ],
      [ "get_channel_mute_status", "classopenmpt_1_1ext_1_1interactive.html#acf307cb660c1f5f3a0d04a052858a263", null ],
      [ "get_channel_volume", "classopenmpt_1_1ext_1_1interactive.html#aa54bc484eed722422107b5de8913ab8c", null ],
      [ "get_global_volume", "classopenmpt_1_1ext_1_1interactive.html#a8e32b907f665b3fc6b1d7ed668efc71c", null ],
      [ "get_instrument_mute_status", "classopenmpt_1_1ext_1_1interactive.html#a48d7a7cdf48c1b18ecd55b05a01013ef", null ],
      [ "get_pitch_factor", "classopenmpt_1_1ext_1_1interactive.html#a39d20ad6bdc958a09e19cf99cffeb67d", null ],
      [ "get_tempo_factor", "classopenmpt_1_1ext_1_1interactive.html#a18a43abf4d28a5c2a6b6ab4e2c3eeeec", null ],
      [ "play_note", "classopenmpt_1_1ext_1_1interactive.html#a9ac033b5c0f0cce7ff65b3258254bd9a", null ],
      [ "set_channel_mute_status", "classopenmpt_1_1ext_1_1interactive.html#a4aca685550ce5adb7a525d45f4872861", null ],
      [ "set_channel_volume", "classopenmpt_1_1ext_1_1interactive.html#a62f10ec3f8535971820e248fd39db75c", null ],
      [ "set_current_speed", "classopenmpt_1_1ext_1_1interactive.html#a7364c32129d1f1c19e878d3470c85b4e", null ],
      [ "set_current_tempo", "classopenmpt_1_1ext_1_1interactive.html#acda3b7ce32d69998b047dddca7217589", null ],
      [ "set_global_volume", "classopenmpt_1_1ext_1_1interactive.html#a21b996a4cd1baedca4a48b28319b611c", null ],
      [ "set_instrument_mute_status", "classopenmpt_1_1ext_1_1interactive.html#a902afe9f902bc0c6cd018a83e83d8446", null ],
      [ "set_pitch_factor", "classopenmpt_1_1ext_1_1interactive.html#a5c1edcf89b889efe65b1531e5c2df29c", null ],
      [ "set_tempo_factor", "classopenmpt_1_1ext_1_1interactive.html#a90ed28d6196524620a7dc8f7902fb40d", null ],
      [ "stop_note", "classopenmpt_1_1ext_1_1interactive.html#a49312b686b28617c07d414de015fb4e9", null ]
    ] ],
    [ "LIBOPENMPT_DECLARE_EXT_CXX_INTERFACE", "group__libopenmpt__ext__cpp.html#ga3d4204c38db54ffee969b9313fa07ed0", null ],
    [ "LIBOPENMPT_EXT_CXX_INTERFACE", "group__libopenmpt__ext__cpp.html#ga614654e47f4238cd49607ed3111300db", null ],
    [ "LIBOPENMPT_EXT_INTERFACE_INTERACTIVE", "group__libopenmpt__ext__cpp.html#ga37c26cb578e858d4272f16e9afb2bf5c", null ],
    [ "LIBOPENMPT_EXT_INTERFACE_PATTERN_VIS", "group__libopenmpt__ext__cpp.html#ga7fc1f2bf7c26ed675c2b28fc855bf394", null ],
    [ "interactive_id", "group__libopenmpt__ext__cpp.html#gad512c56795b5db030926f0f4b1cbce7a", null ],
    [ "pattern_vis_id", "group__libopenmpt__ext__cpp.html#gac9a8f10e0115843aa2b8668247446a2b", null ]
];

==> libopenmpt-0.6.27-pre.0+r24693.doc.tar.gz: libopenmpt-0.6.27-pre.0+r24693.doc/docs/group__libopenmpt__ext__cpp.js <==
var group__libopenmpt__ext__cpp =
[
    [ "module_ext", "classopenmpt_1_1module__ext.html", [
      [ "module_ext", "classopenmpt_1_1module__ext.html#a4994cb67b264d14aa849ec2067c6076b", null ],
      [ "module_ext", "classopenmpt_1_1module__ext.html#a6239cf674bdc9c66c2a64e395af75239", null ],
      [ "module_ext", "classopenmpt_1_1module__ext.html#a829d531759384308ee9fc20b6df26b43", null ],
      [ "module_ext", "classopenmpt_1_1module__ext.html#a31595d7291f0a1fec0f827f1a4a3296d", null ],
      [ "module_ext", "classopenmpt_1_1module__ext.html#ad1cf4592315eab8065d6fcf753473baa", null ],
      [ "module_ext", "classopenmpt_1_1module__ext.html#af9754b9824e502557c73c088ed7651ea", null ],
      [ "module_ext", "classopenmpt_1_1module__ext.html#a7914d17a610f62eb3b5e8cddeaacbec8", null ],
      [ "module_ext", "classopenmpt_1_1module__ext.html#ac7eaa75faea847d4a63c37e95f745d7a", null ],
      [ "~module_ext", "classopenmpt_1_1module__ext.html#a24ad229c4c23cd7ec9de328e09cdf3dc", null ],
      [ "get_interface", "classopenmpt_1_1module__ext.html#aa98f2d2bb046ea2bc346b8f4839c65ce", null ]
    ] ],
    [ "pattern_vis", "classopenmpt_1_1ext_1_1pattern__vis.html", [
      [ "effect_type", "classopenmpt_1_1ext_1_1pattern__vis.html#a42fdf7dfd8919fa42a8bbb7754cccde3", [
        [ "effect_unknown", "classopenmpt_1_1ext_1_1pattern__vis.html#a42fdf7dfd8919fa42a8bbb7754cccde3af10aa914735334b1de44aeec4870345a", null ],
        [ "effect_general", "classopenmpt_1_1ext_1_1pattern__vis.html#a42fdf7dfd8919fa42a8bbb7754cccde3a2723a45bc3a57aefe507bcc7e8729ede", null ],
        [ "effect_global", "classopenmpt_1_1ext_1_1pattern__vis.html#a42fdf7dfd8919fa42a8bbb7754cccde3a4431ac360b49a3381f32e3c50c8350e9", null ],
        [ "effect_volume", "classopenmpt_1_1ext_1_1pattern__vis.html#a42fdf7dfd8919fa42a8bbb7754cccde3a795774dd8f93ab5714e7961449be5f8c", null ],
        [ "effect_panning", "classopenmpt_1_1ext_1_1pattern__vis.html#a42fdf7dfd8919fa42a8bbb7754cccde3a7cb096c0556b747289cc9f0136f09be0", null ],
        [ "effect_pitch", "classopenmpt_1_1ext_1_1pattern__vis.html#a42fdf7dfd8919fa42a8bbb7754cccde3a1c789ea5244b97959b9b960094e8614e", null ]
      ] ],
      [ "pattern_vis", "classopenmpt_1_1ext_1_1pattern__vis.html#a6f346c9132d63b48a3217983f8570888", null ],
      [ "~ pattern_vis", "classopenmpt_1_1ext_1_1pattern__vis.html#a269636fa2e1e5a867ee7b093c5589283", null ],
      [ "get_pattern_row_channel_effect_type", "classopenmpt_1_1ext_1_1pattern__vis.html#a1c0048a3f55579336b5adcb1c901b90b", null ],
      [ "get_pattern_row_channel_volume_effect_type", "classopenmpt_1_1ext_1_1pattern__vis.html#afc9f85743bf1a24167acb0fcd899c879", null ]
    ] ],
    [ "interactive", "classopenmpt_1_1ext_1_1interactive.html", [
      [ "interactive", "classopenmpt_1_1ext_1_1interactive.html#a905dbc74186d10a96cbd929235300315", null ],
      [ "~ interactive", "classopenmpt_1_1ext_1_1interactive.html#ac4847dc829005331c0e72910e7d81707", null ],
      [ "get_channel_mute_status", "classopenmpt_1_1ext_1_1interactive.html#acf307cb660c1f5f3a0d04a052858a263", null ],
      [ "get_channel_volume", "classopenmpt_1_1ext_1_1interactive.html#aa54bc484eed722422107b5de8913ab8c", null ],
      [ "get_global_volume", "classopenmpt_1_1ext_1_1interactive.html#a8e32b907f665b3fc6b1d7ed668efc71c", null ],
      [ "get_instrument_mute_status", "classopenmpt_1_1ext_1_1interactive.html#a48d7a7cdf48c1b18ecd55b05a01013ef", null ],
      [ "get_pitch_factor", "classopenmpt_1_1ext_1_1interactive.html#a39d20ad6bdc958a09e19cf99cffeb67d", null ],
      [ "get_tempo_factor", "classopenmpt_1_1ext_1_1interactive.html#a18a43abf4d28a5c2a6b6ab4e2c3eeeec", null ],
      [ "play_note", "classopenmpt_1_1ext_1_1interactive.html#a9ac033b5c0f0cce7ff65b3258254bd9a", null ],
      [ "set_channel_mute_status", "classopenmpt_1_1ext_1_1interactive.html#a4aca685550ce5adb7a525d45f4872861", null ],
      [ "set_channel_volume", "classopenmpt_1_1ext_1_1interactive.html#a62f10ec3f8535971820e248fd39db75c", null ],
      [ "set_current_speed", "classopenmpt_1_1ext_1_1interactive.html#a7364c32129d1f1c19e878d3470c85b4e", null ],
      [ "set_current_tempo", "classopenmpt_1_1ext_1_1interactive.html#acda3b7ce32d69998b047dddca7217589", null ],
      [ "set_global_volume", "classopenmpt_1_1ext_1_1interactive.html#a21b996a4cd1baedca4a48b28319b611c", null ],
      [ "set_instrument_mute_status", "classopenmpt_1_1ext_1_1interactive.html#a902afe9f902bc0c6cd018a83e83d8446", null ],
      [ "set_pitch_factor", "classopenmpt_1_1ext_1_1interactive.html#a5c1edcf89b889efe65b1531e5c2df29c", null ],
      [ "set_tempo_factor", "classopenmpt_1_1ext_1_1interactive.html#a90ed28d6196524620a7dc8f7902fb40d", null ],
      [ "stop_note", "classopenmpt_1_1ext_1_1interactive.html#a49312b686b28617c07d414de015fb4e9", null ]
    ] ],
    [ "interactive2", "classopenmpt_1_1ext_1_1interactive2.html", [
      [ "interactive2", "classopenmpt_1_1ext_1_1interactive2.html#abd9bcf84747cc481fb9701a825308d20", null ],
      [ "~ interactive2", "classopenmpt_1_1ext_1_1interactive2.html#a4da56e6cf975d514d8c504810264b5a3", null ],
      [ "get_channel_panning", "classopenmpt_1_1ext_1_1interactive2.html#a3485cf5100259a128f25f1b4e90e79fe", null ],
      [ "get_note_finetune", "classopenmpt_1_1ext_1_1interactive2.html#aba5629b9837f14ee0b179c215a277876", null ],
      [ "note_fade", "classopenmpt_1_1ext_1_1interactive2.html#ae8000602d9c3fceff0c19e3139a0131c", null ],
      [ "note_off", "classopenmpt_1_1ext_1_1interactive2.html#aca83382556c4f51e95583756fc97988b", null ],
      [ "set_channel_panning", "classopenmpt_1_1ext_1_1interactive2.html#ad4250ed180261b9c0a096fccccb5294f", null ],
      [ "set_note_finetune", "classopenmpt_1_1ext_1_1interactive2.html#a3165d5eea83d990ef3cb9533b4d7dbd4", null ]
    ] ],
    [ "LIBOPENMPT_DECLARE_EXT_CXX_INTERFACE", "group__libopenmpt__ext__cpp.html#ga3d4204c38db54ffee969b9313fa07ed0", null ],
    [ "LIBOPENMPT_EXT_CXX_INTERFACE", "group__libopenmpt__ext__cpp.html#ga614654e47f4238cd49607ed3111300db", null ],
    [ "LIBOPENMPT_EXT_INTERFACE_INTERACTIVE", "group__libopenmpt__ext__cpp.html#ga37c26cb578e858d4272f16e9afb2bf5c", null ],
    [ "LIBOPENMPT_EXT_INTERFACE_INTERACTIVE2", "group__libopenmpt__ext__cpp.html#gac2f12bf6a3b15f922b2ab1526dfed34d", null ],
    [ "LIBOPENMPT_EXT_INTERFACE_PATTERN_VIS", "group__libopenmpt__ext__cpp.html#ga7fc1f2bf7c26ed675c2b28fc855bf394", null ],
    [ "interactive2_id", "group__libopenmpt__ext__cpp.html#ga191dfc4c2f85a215e41213b706ab5840", null ],
    [ "interactive_id", "group__libopenmpt__ext__cpp.html#gad512c56795b5db030926f0f4b1cbce7a", null ],
    [ "pattern_vis_id", "group__libopenmpt__ext__cpp.html#gac9a8f10e0115843aa2b8668247446a2b", null ]
];
